<?php
/*
 * @package Smallbiz Startup
 */

function smallbiz_startup_admin_enqueue_scripts() {
	wp_enqueue_style( 'smallbiz-startup-admin-style', esc_url( get_template_directory_uri() ).'/css/addon.css' );
}
add_action( 'admin_enqueue_scripts', 'smallbiz_startup_admin_enqueue_scripts' );

add_action('after_switch_theme', 'smallbiz_startup_options');

function smallbiz_startup_options () {
	global $pagenow;
	if( is_admin() && 'themes.php' == $pagenow && isset( $_GET['activated'] ) && current_user_can( 'manage_options' ) ) {
		wp_redirect( admin_url( 'themes.php?page=smallbiz-startup' ) );
		exit;
	}
}

if ( ! defined( 'SMALLBIZ_STARTUP_SUPPORT' ) ) {
define('SMALLBIZ_STARTUP_SUPPORT',__('https://wordpress.org/support/theme/smallbiz-startup','smallbiz-startup'));
}
if ( ! defined( 'SMALLBIZ_STARTUP_REVIEW' ) ) {
define('SMALLBIZ_STARTUP_REVIEW',__('https://wordpress.org/support/theme/smallbiz-startup/reviews/#new-post','smallbiz-startup'));
}
if ( ! defined( 'SMALLBIZ_STARTUP_PRO_DEMO' ) ) {
define('SMALLBIZ_STARTUP_PRO_DEMO',__('https://www.theclassictemplates.com/demo/smallbiz-startup/','smallbiz-startup'));
}
if ( ! defined( 'SMALLBIZ_STARTUP_THEME_PAGE' ) ) {
define('SMALLBIZ_STARTUP_THEME_PAGE',__('https://www.theclassictemplates.com/themes/','smallbiz-startup'));
}
if ( ! defined( 'SMALLBIZ_STARTUP_PREMIUM_PAGE' ) ) {
define('SMALLBIZ_STARTUP_PREMIUM_PAGE',__('https://www.theclassictemplates.com/wp-themes/wordpress-startup-theme/','smallbiz-startup'));
}

function smallbiz_startup_theme_info_menu_link() {

	$theme = wp_get_theme();
	add_theme_page(
		sprintf( esc_html__( 'Welcome to %1$s %2$s', 'smallbiz-startup' ), $theme->display( 'Name' ), $theme->display( 'Version' ) ),
		esc_html__( 'Theme Info', 'smallbiz-startup' ),'edit_theme_options','smallbiz-startup','smallbiz_startup_theme_info_page'
	);
}
add_action( 'admin_menu', 'smallbiz_startup_theme_info_menu_link' );

function smallbiz_startup_theme_info_page() {

	$theme = wp_get_theme();
	?>
<div class="wrap theme-info-wrap">
	<h1><?php printf( esc_html__( 'Welcome to %1$s %2$s', 'smallbiz-startup' ), esc_html($theme->display( 'Name', 'smallbiz-startup'  )),esc_html($theme->display( 'Version', 'smallbiz-startup' ))); ?>
	</h1>
	<p class="theme-description">
	<?php esc_html_e( 'Do you want to configure this theme? Look no further, our easy-to-follow theme documentation will walk you through it.', 'smallbiz-startup' ); ?>
	</p>
	<hr>
	<div class="important-links clearfix">
		<p><strong><?php esc_html_e( 'Theme Links', 'smallbiz-startup' ); ?>:</strong>
			<a href="<?php echo esc_url( SMALLBIZ_STARTUP_THEME_PAGE ); ?>" target="_blank"><?php esc_html_e( 'Theme Page', 'smallbiz-startup' ); ?></a>
			<a href="<?php echo esc_url( SMALLBIZ_STARTUP_SUPPORT ); ?>" target="_blank"><?php esc_html_e( 'Contact Us', 'smallbiz-startup' ); ?></a>
			<a href="<?php echo esc_url( SMALLBIZ_STARTUP_REVIEW ); ?>" target="_blank"><?php esc_html_e( 'Rate This Theme', 'smallbiz-startup' ); ?></a>
			<a href="<?php echo esc_url( SMALLBIZ_STARTUP_PRO_DEMO ); ?>" target="_blank"><?php esc_html_e( 'Premium Demo', 'smallbiz-startup' ); ?></a>
			<a href="<?php echo esc_url( SMALLBIZ_STARTUP_PREMIUM_PAGE ); ?>" target="_blank"><?php esc_html_e( 'Go To Premium', 'smallbiz-startup' ); ?></a>
		</p>
	</div>
	<hr>
	<div id="getting-started">
		<h3><?php printf( esc_html__( 'Getting started with %s', 'smallbiz-startup' ), 
		esc_html($theme->display( 'Name', 'smallbiz-startup' ))); ?></h3>
		<div class="columns-wrapper clearfix">
			<div class="column column-half clearfix">
				<div class="section">
					<h4><?php esc_html_e( 'Theme Description', 'smallbiz-startup' ); ?></h4>
					<div class="theme-description-1"><?php echo esc_html($theme->display( 'Description' )); ?></div>
				</div>
			</div>
			<div class="column column-half clearfix">
				<img src="<?php echo esc_url( $theme->get_screenshot() ); ?>" />
				<div class="section">
					<h4><?php esc_html_e( 'Theme Options', 'smallbiz-startup' ); ?></h4>
					<p class="about">
					<?php printf( esc_html__( '%s makes use of the Customizer for all theme settings. Click on "Customize Theme" to open the Customizer now.', 'smallbiz-startup' ),esc_html($theme->display( 'Name', 'smallbiz-startup' ))); ?></p>
					<p>
					<a href="<?php echo esc_attr(wp_customize_url()); ?>" class="button button-primary" target="_blank"><?php esc_html_e( 'Customize Theme', 'smallbiz-startup' ); ?></a>
					<a href="<?php echo esc_url( SMALLBIZ_STARTUP_PREMIUM_PAGE ); ?>" target="_blank" class="button button-secondary premium-btn"><?php esc_html_e( 'Checkout Premium', 'smallbiz-startup' ); ?></a></p>
				</div>
			</div>
		</div>
	</div>
	<hr>
	<div id="theme-author">
	  <p><?php
		printf( esc_html__( '%1$s is proudly brought to you by %2$s. If you like this theme, %3$s :)', 'smallbiz-startup' ),
			esc_html($theme->display( 'Name', 'smallbiz-startup' )),
			'<a target="_blank" href="' . esc_url( 'https://www.theclassictemplates.com/', 'smallbiz-startup' ) . '">classictemplate</a>',
			'<a target="_blank" href="' . esc_url( SMALLBIZ_STARTUP_REVIEW ) . '" title="' . esc_attr__( 'Rate it', 'smallbiz-startup' ) . '">' . esc_html_x( 'rate it', 'If you like this theme, rate it', 'smallbiz-startup' ) . '</a>'
		)
		?></p>
	</div>
</div>
<?php
}
